@@ -4,8 +4,10 @@
 import sqlite3
 import pandas as pd
 
-from datetime import datetime
 from napoleontoolbox.file_saver import dropbox_file_saver
+from napoleontoolbox.signal import signal_utility
+import json
+import hashlib
 
 class ParallelRunResultAnalyzer():
 
@@ -59,7 +61,7 @@ class ParallelRunResultAnalyzer():
                 print("The Sqlite connection is closed")
         return results_df
 
-    def analyzeAllRunResults(self):
+    def analyzeAllRunResults(self,jsonized_output = True):
         sqliteConnection = None
         try:
             sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
@@ -83,6 +85,18 @@ class ParallelRunResultAnalyzer():
         self.empty_runs_to_investigate = list(run_empty_results.index[run_empty_results == 0])
 
         results_df = results_df.drop(columns=self.empty_runs_to_investigate)
+
+        if not jsonized_output :
+            renaming_dictionary = {}
+            for col in results_df.columns:
+                if col != 'Date':
+                    run_json_string=signal_utility.recover_to_sql_column_format(col)
+                    params = json.loads(run_json_string)
+                    #salty = hashlib.sha256(run_json_string)
+                    salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
+                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+salty
+
+            results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
         return results_df
 
 
